ODTbrain documentation
======================


Content
-------
.. toctree::
   :maxdepth: 4
   
   index
    
For an alphabetically sorted list of all methods, see :ref:`genindex`.


Introduction
------------
.. automodule:: odtbrain


.. include:: ./doc_include/_br.txt
   

.. include:: ./doc_include/_Back_2D.txt

   
.. include:: ./doc_include/_Back_3D.txt


Examples
========

.. automodule:: backprop_from_mie_2d_cylinder_noncentered

.. automodule:: backprop_2d_weights_angles

.. automodule:: backprop_2d_incomplete_coverage

.. automodule:: backprop_from_fdtd_2d

.. automodule:: backprop_from_mie_3d_sphere

.. automodule:: backprop_from_fdtd_3d

.. automodule:: backprop_from_fdtd_3d_tilted

.. automodule:: backprop_from_fdtd_3d_tilted2


References
==========
.. [1] P. Müller, M. Schürmann, and J. Guck, *The Theory of Diffraction
       Tomography*. `arXiv:1507.00466 <http://arxiv.org/abs/1507.00466>`_
       [q-bio.QM] (2015)
       
.. [2] P. Müller, M. Schürmann, and J. Guck, *ODTbrain: a Python library
       for full-view, dense diffraction tomography*. BMC Bioinformatics
       2015, **16**:367, `doi:10.1186/s12859-015-0764-0 
       <http://dx.doi.org/10.1186/s12859-015-0764-0>`_ (2015)

.. [3] P. Müller, M. Schürmann, C. J. Chan, and J. Guck, *Single-cell
       diffraction tomography with optofluidic rotation about a tilted axis*.
       Proc. of SPIE, `doi:10.1117/12.2191501 
       <http://dx.doi.org/10.1117/12.2191501>`_ (2015)

.. [4] A. C. Kak and M. Slaney, *Principles of Computerized Tomographic Imaging*.
       Philadelphia, USA: SIAM, `doi:10.1137/1.9780898719277 
       <http://dx.doi.org/10.1137/1.9780898719277>`_ (2001)

.. [5] E. Wolf, *Three-dimensional structure determination of semi-transparent
       objects from holographic data*. Opt. Commun., vol. 1, no. 4, pp. 153–156,
       `doi:10.1016/0030-4018(69)90052-2  
       <http://dx.doi.org/10.1016/0030-4018(69)90052-2>`_ (1969)

.. [6] K. C. Tam and V. Perez-Mendez, *Tomographical imaging with limited-angle input*,
       J. Opt. Soc. Am., vol. 71, no. 5, pp. 582–592, `doi:10.1364/JOSA.71.000582  
       <http://dx.doi.org/10.1016/10.1364/JOSA.71.000582>`_ (1981)
